=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2013-02-15 15:07:55 +0000
+++ CMakeLists.txt	2013-04-03 13:50:54 +0000
@@ -7,7 +7,7 @@
 
 option(enable_tests "Enable tests." ON)
 option(enable_scalability_tests "Additional scalability tests that are potentially very slow to run." OFF)
-option(full_warnings "Full compiler warnings." ON)
+option(full_warnings "All possible compiler warnings." OFF)
 option(debug_messages "Print debug messages.")
 option(full_unicode "Enable full Unicode support (takes lots of memory).")
 option(use_python2 "Build Python bindings against Python 2 (UNSUPPORTED)." OFF)
@@ -21,9 +21,11 @@
 include(cmake/python.cmake)
 include(cmake/coverage.cmake)
 
+set(CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -Wall -pedantic -Wextra")
+set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -Wall -pedantic -Wextra")
 if(${full_warnings})
-  set(CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -Wall -pedantic")
-  set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -Wall -pedantic")
+# C does not have any more warning flags.
+  set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -Weffc++")
 endif()
 
 if(${debug_messages})

=== modified file 'include/ColumbusCore.hh.in'
--- include/ColumbusCore.hh.in	2013-01-30 10:21:36 +0000
+++ include/ColumbusCore.hh.in	2013-04-03 13:50:54 +0000
@@ -47,6 +47,8 @@
   #endif
 #endif
 
+#define UNUSED_VAR __attribute__ ((unused))
+
 #ifdef __cplusplus
   #include <cstddef>
   #include <cstdint>

=== modified file 'src/IndexMatches.cc'
--- src/IndexMatches.cc	2012-12-07 11:01:33 +0000
+++ src/IndexMatches.cc	2013-04-03 13:50:54 +0000
@@ -50,7 +50,7 @@
     delete p;
 }
 
-void IndexMatches::addMatch(const Word &queryWord, const WordID matchedWord, int error) {
+void IndexMatches::addMatch(const Word &/*queryWord*/, const WordID matchedWord, int error) {
     MatchData m;
     m.matchedWord = matchedWord;
     m.error = error;

=== modified file 'src/Matcher.cc'
--- src/Matcher.cc	2013-01-30 15:21:02 +0000
+++ src/Matcher.cc	2013-04-03 13:50:54 +0000
@@ -153,7 +153,7 @@
         return int((1+len/4.0)*LevenshteinIndex::getDefaultError()); // Permit a typo for every fourth letter.
 }
 
-static void addMatches(MatcherPrivate *p, BestIndexMatches &bestIndexMatches, const Word &queryWord, const WordID indexID, IndexMatches &matches) {
+static void addMatches(MatcherPrivate */*p*/, BestIndexMatches &bestIndexMatches, const Word &/*queryWord*/, const WordID indexID, IndexMatches &matches) {
     MatchIndIterator it = bestIndexMatches.find(indexID);
     map<WordID, int> *indexMatches;
     if(it == bestIndexMatches.end()) {

=== modified file 'src/MatcherStatistics.cc'
--- src/MatcherStatistics.cc	2013-01-30 13:48:22 +0000
+++ src/MatcherStatistics.cc	2013-04-03 13:50:54 +0000
@@ -64,7 +64,7 @@
 
 }
 
-void MatcherStatistics::addedWordToIndex(const WordID word, const Word &fieldName) {
+void MatcherStatistics::addedWordToIndex(const WordID /*word*/, const Word &/*fieldName*/) {
     // Doesn't do anything yet.
 }
 

=== modified file 'test/CAPITest.c'
--- test/CAPITest.c	2013-02-18 10:34:40 +0000
+++ test/CAPITest.c	2013-04-03 13:50:54 +0000
@@ -118,7 +118,7 @@
     col_matcher_delete(m);
 }
 
-int main(int argc, char **argv) {
+int main(int argc UNUSED_VAR, char **argv UNUSED_VAR) {
     testWord();
     testDocument();
     testMatcher();

=== modified file 'test/CorpusTest.cc'
--- test/CorpusTest.cc	2013-01-17 08:58:37 +0000
+++ test/CorpusTest.cc	2013-04-03 13:50:54 +0000
@@ -66,7 +66,7 @@
     assert(lNew[1] == w4);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testCorpus();
     } catch(const std::exception &e) {

=== modified file 'test/CustomErrorTest.cc'
--- test/CustomErrorTest.cc	2013-01-17 08:58:37 +0000
+++ test/CustomErrorTest.cc	2013-04-03 13:50:54 +0000
@@ -67,7 +67,7 @@
 
 
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testCustomError();
     } catch(const std::exception &e) {

=== modified file 'test/DocumentTest.cc'
--- test/DocumentTest.cc	2013-01-17 08:58:37 +0000
+++ test/DocumentTest.cc	2013-04-03 13:50:54 +0000
@@ -144,7 +144,7 @@
     assert(d.totalWordCount(w4) == 2);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testDoc();
         testIndexNames();

=== modified file 'test/ErrorValuesTest.cc'
--- test/ErrorValuesTest.cc	2013-01-17 08:58:37 +0000
+++ test/ErrorValuesTest.cc	2013-04-03 13:50:54 +0000
@@ -106,7 +106,7 @@
     assert(ev.getSubstituteError('j', '6') < ErrorValues::getDefaultError());
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testError();
         testGroupError();

=== modified file 'test/HelpersTest.cc'
--- test/HelpersTest.cc	2013-01-17 08:58:37 +0000
+++ test/HelpersTest.cc	2013-04-03 13:50:54 +0000
@@ -62,7 +62,7 @@
     assert(l.size() == 3);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testSplitter();
         testWeirdWord();

=== modified file 'test/IndexWeightsTest.cc'
--- test/IndexWeightsTest.cc	2013-01-17 08:58:37 +0000
+++ test/IndexWeightsTest.cc	2013-04-03 13:50:54 +0000
@@ -32,7 +32,7 @@
     assert(w.getWeight(w1) == 2.0);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testWeights();
     } catch(const std::exception &e) {

=== modified file 'test/LevIndexTest.cc'
--- test/LevIndexTest.cc	2013-01-17 08:58:37 +0000
+++ test/LevIndexTest.cc	2013-04-03 13:50:54 +0000
@@ -305,7 +305,7 @@
     assert(matches.getMatch(0) == w1ID);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testTrivial();
         testSimple();

=== modified file 'test/LevTrieTest.cc'
--- test/LevTrieTest.cc	2013-01-17 08:58:37 +0000
+++ test/LevTrieTest.cc	2013-04-03 13:50:54 +0000
@@ -155,7 +155,7 @@
     assert(ind.numWords() == 2);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
 #ifdef NDEBUG
     fprintf(stderr, "NDEBUG is defined, tests will not work!\n");
     return 1;

=== modified file 'test/MatchResultsTest.cc'
--- test/MatchResultsTest.cc	2013-01-17 08:58:37 +0000
+++ test/MatchResultsTest.cc	2013-04-03 13:50:54 +0000
@@ -46,7 +46,7 @@
     assert(r.getRelevancy(0) == r2);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testMatchResult();
     } catch(const std::exception &e) {

=== modified file 'test/MatcherTest.cc'
--- test/MatcherTest.cc	2013-01-17 08:58:37 +0000
+++ test/MatcherTest.cc	2013-04-03 13:50:54 +0000
@@ -127,7 +127,7 @@
     assert(matches.getDocumentID(0) == correct);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testMatcher();
         testRelevancy();

=== modified file 'test/ResultFilterTest.cc'
--- test/ResultFilterTest.cc	2013-01-17 08:58:37 +0000
+++ test/ResultFilterTest.cc	2013-04-03 13:50:54 +0000
@@ -87,7 +87,7 @@
     assert(andResults.size() == 0);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testFiltering();
     } catch(const std::exception &e) {

=== modified file 'test/TrieTest.cc'
--- test/TrieTest.cc	2013-01-31 10:01:17 +0000
+++ test/TrieTest.cc	2013-04-03 13:50:54 +0000
@@ -47,7 +47,7 @@
 }
 
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     // Move basic tests from levtrietest here.
     testWordBuilding();
     return 0;

=== modified file 'test/WordListTest.cc'
--- test/WordListTest.cc	2013-01-17 08:58:37 +0000
+++ test/WordListTest.cc	2013-04-03 13:50:54 +0000
@@ -92,7 +92,7 @@
     assert(l1 != l2);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testList();
         testAssignment();

=== modified file 'test/WordStoreTest.cc'
--- test/WordStoreTest.cc	2013-01-17 08:58:37 +0000
+++ test/WordStoreTest.cc	2013-04-03 13:50:54 +0000
@@ -54,7 +54,7 @@
     assert(gotException);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/*argv*/) {
     try {
         testStore();
     } catch(const std::exception &e) {

=== modified file 'test/WordTest.cc'
--- test/WordTest.cc	2013-01-17 08:58:37 +0000
+++ test/WordTest.cc	2013-04-03 13:50:54 +0000
@@ -270,7 +270,7 @@
     assert(gotAssertion);
 }
 
-int main(int argc, char **argv) {
+int main(int /*argc*/, char **/* argv*/) {
     try {
         testEmpty();
         testIndexing();

=== modified file 'tools/hudtest.cc'
--- tools/hudtest.cc	2013-01-17 09:17:28 +0000
+++ tools/hudtest.cc	2013-04-03 13:50:54 +0000
@@ -48,16 +48,16 @@
     vector<string> pathSource, commandSource;
 };
 
-static gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
+static gboolean delete_event(GtkWidget */*widget*/, GdkEvent */*event*/, gpointer /*data*/) {
     gtk_main_quit();
     return TRUE;
 }
 
-static void destroy(GtkWidget *widget, gpointer data) {
+static void destroy(GtkWidget */*widget*/, gpointer /*data*/) {
     gtk_main_quit ();
 }
 
-static void doSearch(GtkWidget *widget, gpointer data) {
+static void doSearch(GtkWidget */*widget*/, gpointer data) {
     app_data *app = (app_data*) data;
     MatchResults matches;
     GtkTreeIter iter;

=== modified file 'tools/numberpad.cc'
--- tools/numberpad.cc	2013-01-17 09:09:14 +0000
+++ tools/numberpad.cc	2013-04-03 13:50:54 +0000
@@ -46,12 +46,12 @@
     const char *filename;
 };
 
-static gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
+static gboolean delete_event(GtkWidget */*widget*/, GdkEvent */*event*/, gpointer /*data*/) {
     gtk_main_quit();
     return TRUE;
 }
 
-static void destroy(GtkWidget *widget, gpointer data) {
+static void destroy(GtkWidget */*widget*/, gpointer /*data*/) {
     gtk_main_quit ();
 }
 
@@ -82,7 +82,7 @@
     printf("\n\n");
 }
 
-static void doSearch(GtkWidget *widget, gpointer data) {
+static void doSearch(GtkWidget */*widget*/, gpointer data) {
     app_data *app = (app_data*) data;
     MatchResults matches;
     GtkTreeIter iter;

=== modified file 'tools/queryapp.cc'
--- tools/queryapp.cc	2013-01-17 09:09:14 +0000
+++ tools/queryapp.cc	2013-04-03 13:50:54 +0000
@@ -45,16 +45,16 @@
     vector<string> source;
 };
 
-static gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
+static gboolean delete_event(GtkWidget */*widget*/, GdkEvent */*event*/, gpointer /*data*/) {
     gtk_main_quit();
     return TRUE;
 }
 
-static void destroy(GtkWidget *widget, gpointer data) {
+static void destroy(GtkWidget */*widget*/, gpointer /*data*/) {
     gtk_main_quit ();
 }
 
-static void doSearch(GtkWidget *widget, gpointer data) {
+static void doSearch(GtkWidget */*widget*/, gpointer data) {
     app_data *app = (app_data*) data;
     MatchResults matches;
     GtkTreeIter iter;

=== modified file 'tools/sctest.cc'
--- tools/sctest.cc	2013-01-17 09:09:14 +0000
+++ tools/sctest.cc	2013-04-03 13:50:54 +0000
@@ -54,12 +54,12 @@
     vector<string> names;
 };
 
-static gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
+static gboolean delete_event(GtkWidget */*widget*/, GdkEvent */*event*/, gpointer /*data*/) {
     gtk_main_quit();
     return TRUE;
 }
 
-static void destroy(GtkWidget *widget, gpointer data) {
+static void destroy(GtkWidget */*widget*/, gpointer /*data*/) {
     gtk_main_quit ();
 }
 
@@ -81,7 +81,7 @@
 }
 
 
-static void doSearch(GtkWidget *widget, gpointer data) {
+static void doSearch(GtkWidget */*widget*/, gpointer data) {
     app_data *app = (app_data*) data;
     MatchResults matches;
     double updateStart, updateEnd;

=== modified file 'tools/singleword.cc'
--- tools/singleword.cc	2013-01-17 09:09:14 +0000
+++ tools/singleword.cc	2013-04-03 13:50:54 +0000
@@ -52,16 +52,16 @@
     GtkWidget *errorSpinner;
 };
 
-static gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data) {
+static gboolean delete_event(GtkWidget */*widget*/, GdkEvent */*event*/, gpointer /*data*/) {
     gtk_main_quit();
     return TRUE;
 }
 
-static void destroy(GtkWidget *widget, gpointer data) {
+static void destroy(GtkWidget */*widget*/, gpointer /*data*/) {
     gtk_main_quit ();
 }
 
-static void doSearch(GtkWidget *widget, gpointer data) {
+static void doSearch(GtkWidget */*widget*/, gpointer data) {
     app_data *app = (app_data*) data;
     IndexMatches matches;
     GtkTreeIter iter;

